@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-06'; # DATE
+our $DATE = '2024-02-02'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.033'; # VERSION
+our $VERSION = '1.034'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
@@ -69,8 +69,8 @@ second not in the first:
     4,5,6
     4,5,7
 
-You can specify `--compare-fields` to only consider some fields only, for
-example `--union --compare-fields a,b file1.csv file2.csv`:
+You can specify `--compare-fields` to consider some fields only, for example
+`--union --compare-fields a,b file1.csv file2.csv`:
 
     a,b,c
     1,2,3
@@ -344,7 +344,7 @@ App::CSVUtils::csv_setop - Set operation (union/unique concatenation of rows, in
 
 =head1 VERSION
 
-This document describes version 1.033 of App::CSVUtils::csv_setop (from Perl distribution App-CSVUtils), released on 2023-09-06.
+This document describes version 1.034 of App::CSVUtils::csv_setop (from Perl distribution App-CSVUtils), released on 2024-02-02.
 
 =head1 FUNCTIONS
 
@@ -408,8 +408,8 @@ second not in the first:
  4,5,6
  4,5,7
 
-You can specify C<--compare-fields> to only consider some fields only, for
-example C<--union --compare-fields a,b file1.csv file2.csv>:
+You can specify C<--compare-fields> to consider some fields only, for example
+C<--union --compare-fields a,b file1.csv file2.csv>:
 
  a,b,c
  1,2,3
@@ -662,7 +662,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
